@@ -1,6 +1,7 @@
 import re
 
 from six import string_types
+from samtranslator.model.exceptions import InvalidTemplateException, InvalidDocumentException
 
 
 class Action(object):
@@ -371,7 +372,7 @@ class SubAction(Action):
         """
 
         # RegExp to find pattern "${logicalId.property}" and return the word inside bracket
-        logical_id_regex = '[A-Za-z0-9\.]+'
+        logical_id_regex = '[A-Za-z0-9\.]+|AWS::[A-Z][A-Za-z]*'
         ref_pattern = re.compile(r'\$\{(' + logical_id_regex + ')\}')
 
         # Find all the pattern, and call the handler to decide how to substitute them.
@@ -426,6 +427,11 @@ class GetAttAction(Action):
         if not isinstance(value, list) or len(value) < 2:
             return input_dict
 
+        if (not all(isinstance(entry, string_types) for entry in value)):
+            raise InvalidDocumentException(
+                [InvalidTemplateException('Invalid GetAtt value {}. GetAtt expects an array with 2 strings.'
+                                          .format(value))])
+
         # Value of GetAtt is an array. It can contain any number of elements, with first being the LogicalId of
         # resource and rest being the attributes. In a SAM template, a reference to a resource can be used in the
         # first parameter. However tools like AWS CLI might break them down as well. So let's just concatenate
@@ -503,3 +509,47 @@ class GetAttAction(Action):
             input_dict[key] = [resolved_value] + remaining
 
         return input_dict
+
+
+class FindInMapAction(Action):
+    """
+    This action can't be used along with other actions.
+    """
+    intrinsic_name = "Fn::FindInMap"
+
+    def resolve_parameter_refs(self, input_dict, parameters):
+        """
+        Recursively resolves "Fn::FindInMap"references that are present in the mappings and returns the value.
+        If it is not in mappings, this method simply returns the input unchanged.
+
+        :param input_dict: Dictionary representing the FindInMap function. Must contain only one key and it
+                           should be "Fn::FindInMap".
+
+        :param parameters: Dictionary of mappings from the SAM template
+        """
+        if not self.can_handle(input_dict):
+            return input_dict
+
+        value = input_dict[self.intrinsic_name]
+
+        # FindInMap expects an array with 3 values
+        if not isinstance(value, list) or len(value) != 3:
+            raise InvalidDocumentException(
+                [InvalidTemplateException('Invalid FindInMap value {}. FindInMap expects an array with 3 values.'
+                                          .format(value))])
+
+        map_name = self.resolve_parameter_refs(value[0], parameters)
+        top_level_key = self.resolve_parameter_refs(value[1], parameters)
+        second_level_key = self.resolve_parameter_refs(value[2], parameters)
+
+        if not isinstance(map_name, string_types) or \
+                not isinstance(top_level_key, string_types) or \
+                not isinstance(second_level_key, string_types):
+            return input_dict
+
+        if map_name not in parameters or \
+                top_level_key not in parameters[map_name] or \
+                second_level_key not in parameters[map_name][top_level_key]:
+            return input_dict
+
+        return parameters[map_name][top_level_key][second_level_key]
